
<#
.SYNOPSIS
    A utility to remove the junk Windows Store Apps. 

.DESCRIPTION
    1. Gets a list of all the AppX programs installed for all users
    2. Filters out stuff we can't or shouldn't remove
    3. Provides user with an Out-Gridview list to choose which apps to uninstall
    4. Uninstalls the apps that the user selects

.EXAMPLE
    By itself:
    Clean-AppXPackages

.EXAMPLE
    On a remote machine:
    Invoke-Command -ComputerName "UserPC1" -ScriptBlock {Clean-AppXPackages}

.NOTES
    Author:    Cameron Ratchford
    Date:      January 9, 2020  
#>

function Clean-AppXPackages
{
    $apps = Get-AppxPackage -AllUsers | Select-Object * | Where-Object -FilterScript { ($_.IsFramework -ne $True) -and ($_.NonRemovable -eq $False) -and ($_.Name -notmatch "Microsoft.WindowsCalculator") -and ($_.Name -notmatch "Microsoft.WindowsTerminal") -and ($_.Name -notmatch "Microsoft.WindowsStore") -and ($_.Name -notmatch "Microsoft.ScreenSketch")} | Out-GridView -Title "Select which AppX programs you'd like to remove" -PassThru
    foreach ($app in $apps)
    {
        Remove-AppPackage -Package $app.PackageFullName -AllUsers 
    }
}
