<#
.SYNOPSIS
    A PowerShell wrapper for the CMD Expand command. So I don't have to look up the syntax for the command everytime I want to unpack a driverpack file.

.DESCRIPTION
    1. Takes cab file, and destination folder
    2. Unpacks all contents of cab file to destination folder
    
.PARAMETER CabFile
    The string path of the cab file to be unpacked
    
.PARAMETER OutputFolder
    The string path of a folder where you would like the cab's contents to end up

.EXAMPLE
    "Unpack-Cab -CabFile 'D:\Drivers\T5600-win7-A07-849JK.CAB' -OutputFolder ." will unpack the contents of T5600-win7-A07-849JK.CAB into the current working directory.

.EXAMPLE
"Unpack-Cab -CabFile '\\ntsvr\apps\DELL\7760\7760 AIO-WIN10-A04-8CKRP.CAB' -OutputFolder 'G:\'" will unpack the contents of the  '7760 AIO-WIN10-A04-8CKRP.CAB file on a network share' onto the removable storage drive G:\

.NOTES
    Author: Cameron Ratchford
    Date:   December 9, 2020   
#>

function Expand-Cab 
{
    [CmdletBinding()]
    param (
        [Parameter(Mandatory=$true)]
        [ValidateNotNullOrEmpty()]
        [string]$CabFile,
        [Parameter(Mandatory=$true)]
        [ValidateNotNullOrEmpty()]
        [string]$OutputFolder
    )

        $Params = @{
            ScriptBlock = {Param ($CabFile, $OutputFolder) EXPAND $CabFile -F:* "$OutputFolder"}
            ArgumentList = $CabFile, $OutputFolder
        }
        Invoke-Command @Params
    
}