function Export-CMGUserGroupMembership {
    <#
.NOTES
    Author: Cameron Ratchford
    Version 1.0

.SYNOPSIS 
	Gets the group membership of a user and outputs it to a file, for storing on SharePoint as part of the user offboarding process.

.PARAMETER Username
    Specifies an Active Directory user object that you wish to export the group membership from.
    
    Example:    "cameron"

.PARAMETER Outfile
	The full path of the file you wish to export the list of groups to.

    Example:    "C:\Temp\cameron.txt"

.EXAMPLE
    Export-CMGUserGroupMembership -Username "cameron" -Outfile "C:\Temp\cameron.txt"

    This command will collect a list of AD Groups that the user cameron is a member of and export the list to a text file called cameron.txt
    located in the C:\Temp directory.
#>
    param(                        
        [Parameter(Mandatory = $True)]   
            [string]
            $Username
            ,
        [Parameter(Mandatory = $True)]   
            [string]
            $Outfile
        )
        $group_list = Get-ADPrincipalGroupMembership -Identity $Username | Select-Object -Property name | Where-Object -FilterScript {($_ -notmatch "ReportingGroup") -and ($_ -notmatch "UserGroup")}
        $group_list | Out-File -FilePath $Outfile
        Write-Host "Group membership exported to $Outfile"
        Get-Content -Path $Outfile
}