<#
.SYNOPSIS
    Initiates a USMT transfer of a specific user from a source computer to a destination computer.
.DESCRIPTION
    Extends "\\ntsvr\apps\Admin\Scripts\PS Function Library\Invoke-USMT.ps1" to make it more user friendly.
    Will gather information from user as a wizard, instead of dumping it all as one command.
.EXAMPLE
    Invoke-CMGUSMT
    Follow prompts
.NOTES
    Author: Cameron Ratchford
    Date:   October 21, 2019  
#>

function Invoke-CMGUSMT
{
    $cred = Get-Credential

    $USMTFilesPath = "\\ntsvr\apps\Admin\Scripts\USMT\USMTFiles"
    $Domain = "CMGL"

    # $SourceComputer = Read-Host -Prompt "Enter hostname of source computer (Computer you are copying from)"
    $SourceComputer =  Read-Host -Prompt "Please enter the computer name of the source computer"
    # $DestinationComputer = Read-Host -Prompt "Enter hostname of destination computer (Computer you are copying to)"
    $DestinationComputer = Read-Host -Prompt "Please enter the computer name of the destination computer"
    # $UserName = Read-Host -Prompt "Enter username of user we are copying"
    $UserName = Read-Host -Prompt "Please enter the targer user's username"

    $prompt_sharepath = Read-Host -Prompt "
    Where do you wish to store the MIG file? (Can be 1Gb to 1Tb is size. Will be deleted when done.)
    1) Source PC C:\
    2) Destination PC C:\
    3) \\ntsvr\apps\Admin\USMT$
    4) Custom
    "

    switch($prompt_sharepath)
    {
        1
        {
            $SharePath = "\\" + $SourceComputer + "\c$"
            write-host $SharePath -ForegroundColor Magenta
        }

        2
        {
            $SharePath = "\\" + $DestinationComputer + "\c$"
            write-host $SharePath -ForegroundColor Magenta
        }

        3
        {
            $SharePath = '\\ntsvr\apps\Admin\USMT$'
            write-host $SharePath -ForegroundColor Magenta
        }

        4
        {
            $SharePath = Read-Host "Path to store MIG File:"
            write-host $SharePath -ForegroundColor Magenta
        }
    }

    $exclusions = $true
    $response_exclusions = Read-Host -Prompt "Exclude D:\, E:\, F:\ drives?  ( [Y] , N )"
    if ($response_exclusions -eq "Y" -or $response_exclusions -eq "y")
    {
        $exclusions = $true
    }

    elseif ($response_exclusions -eq "N" -or $response_exclusions -eq "n") 
    {
        $exclusions = $false
    }


    write-host "
    Here is the provided information:
    
    Source Computer:        $SourceComputer
    Destination Computer:   $DestinationComputer
    Username:               $UserName 
    Exclude D:\, E:\, F:\ : $exclusions
    Mig Storage Path:       $SharePath
    Domain:                 $Domain
    "
    $prompt_continue = Read-Host -Prompt "Do you wish to continue? ( [Y] , N )"
    $continue = $true

    if ($prompt_continue -eq "Y" -or $prompt_continue -eq "y")
    {
        $continue = $true
    }

    elseif ($prompt_continue -eq "N" -or $prompt_continue -eq "n") 
    {
        $continue = $false
    }

    if ($continue)
    {
        invoke-usmt -SourceComputer $SourceComputer -DestinationComputer $DestinationComputer -UserName $UserName -SharePath $SharePath -USMTFilesPath $USMTFilesPath -Domain $Domain -exclusions $exclusions -cred $cred
    }

    else
    {
        write-warning -message "Script escaped..."
        exit
    }

}