<#
.SYNOPSIS
    When the starting of WinRM fails, it is required to run "WinRM QuickConfig". This script will execute that command on a remote computer using PSExec.

.DESCRIPTION
    1. Forces the copy of psexec64.exe to the machine running the script
    2. Opens a powershell shell on the remote computer with PSExec, executing "Set-WSManQuickConfig -Force"
    
.PARAMETER ComputerName
    The string name of the computer you wish to start WinRM on

.PARAMETER Credential
    Optional parameter if you already have a PSCredential Object from the script that you're using this in. If this parameter is not supplied, the script will create as PSCredential object using get-credential

.NOTES
    Author:                 Cameron Ratchford
    Date:                   January 9, 2020  
    Update (Jan 21, 2020):  Added warning message and forced collection of PSCredential Object through CLI rather than the pop-up
                            Added todo
    Update (Jan 24, 2020):  Added flow logic, moved the prompt for creds, tests for winrm service, then runs "Set-WSManQuickConfig" if it still isn't working after.
    Update (Feb 13, 2020):  Removed prompt for credentials and any evokation of credentials. Not necessary when running as admin.
    Update (Feb 27, 2020):  Reduced and cleaned up output. PSExec64 now runs on the remote computer as the system user. This is effective more often than normal administrator users.

#>

function Repair-WinRM-Single
{
    [CmdletBinding()]
    param (
        [Parameter(Mandatory=$true)]
        [string]$ComputerName
    )
    # Variables that might need to be changed
    $PSExecSource = "\\ntsvr\apps\Admin\Scripts\USMT\USMTFiles\PsExec64.exe"
    $PSExecHost = "C:\Windows\System32\"

    # For flow logic, if it's false, it won't attempt running Set-WSManQuickConfig
    $QuickConfig = $false

    try
    {
        Write-Host -NoNewline -ForegroundColor Yellow "`nTesting WinRM on ${ComputerName}: "
        $Success = Test-WSMan -ComputerName $ComputerName -Authentication Default -ErrorAction Stop
        if($Success) {    
            Write-Host -ForegroundColor Green "[OK]"
        }
    }
    catch
    {
        Write-Warning "WinRM service is either not running or not initialized..."
        $QuickConfig = $true
    }


    # If that didn't work, run quickconfig
    if ($QuickConfig)
    {
        write-host "`n`nRunning WinRM QuickConfig`n"
        # Copy PSExec to the computer running this script
        try
        {
            # Copy-Item -Path $PSExecSource -Destination $PSExecHost -Force 
            copy-item -Path "\\ntsvr\apps\Admin\Scripts\USMT\USMTFiles\PsExec64.exe" -Destination "\\$ComputerName\C$\Windows\System32\" -Force
        }
        catch
        {
            Write-Error $_.message
            Write-Warning -Message "Ensure that you have access to $PSExecSource and the PSExec64.exe is located there`n"
        }

        # Execute Set-WSManQuickConfig via PSExec
        try
        {
            $PSExecParams = @{
                ScriptBlock = { Param($ComputerName) C:\Windows\System32\PsExec64.exe \\$ComputerName -d -s -nobanner powershell.exe "& {Set-WSManQuickConfig -Force};"}
                ArgumentList = $Computername
            }    
            Write-Host @PSExecParams
            Invoke-Command @PSExecParams -ErrorAction Stop | Out-Null
        }
        catch
        {
            Write-Error -Message "`nFailed to run Set-WSManQuickConfig remotely."
        }
        finally 
        {
            try {
                # Testing WinRM again
                # Write-Host -ForegroundColor Yellow "`nConfirming if WinRM is working on $ComputerName"
                $Success = Test-WSMan -ComputerName $ComputerName -Authentication Default -ErrorAction Stop

                if ($Success)
                {
                    Write-Host -ForegroundColor Green "`nWinRM appears to be working on $Computername"
                }
                else 
                {
                    Write-Warning "`nWinRM still doesn't appear to be working on $Computername. Try running 'winrm quickconfig' locally."
                }

            } catch { Write-Warning "`nWinRM still doesn't appear to be working on $Computername. Try running 'winrm quickconfig' locally." }

            Remove-Item -Path "\\$ComputerName\C$\Windows\System32\PsExec64.exe"
        }


    }
}

function Repair-WinRM {
    [CmdletBinding()]
    param (
        [Parameter(Mandatory=$true)]
        [string[]]$ComputerName
    )


    foreach ( $Computer in $ComputerName ) {

        Repair-WinRM-Single -ComputerName $Computer 

    }
}