function set-opennetworkdrive
{
    [CmdletBinding()]
    param (
        [Parameter(Mandatory=$true)]
        [ValidateNotNullOrEmpty()]
        [string]$SharePath,
        [Parameter(Mandatory=$true)]
        [ValidateNotNullOrEmpty()]
        [System.Management.Automation.PSCredential]$cred
    )


    begin 
    {
        $ErrorActionPreference = "SilentlyContinue"
        # Test SharePath path
        if (!(Test-Path -Path $SharePath))
        {
            Write-Warning -Message "Could not connect to $SharePath"
        }

        # Test WinRM Service
        $TargetWimRM = get-service -Name WinRM -ComputerName $ComputerName
        if ($TargetWimRM.Status -eq "Stopped")
        {
            try
            {
                start-service $TargetWimRM
            }
            catch
            {
                Write-Error $_
                break
            }

        }
        $ErrorActionPreference = "Continue"
    }
    
    process 
    {
        $alphabet = @()  
        
        for ([byte]$c = [char]'A'; $c -le [char]'Z'; $c++)  
        {  
            $alphabet += [char]$c  
        }  

        $taken_drives = get-psdrive -PSProvider FileSystem
        $available_drives = @()
        $letters = @()
        $drive_letters = @()

        foreach ($letter in $alphabet)
        {
            $let = $letter.ToString()
            $letters += $let
        }

        foreach ($letter in $taken_drives)
        {
            $let = $letter.name.ToString()
            $drive_letters += $let
        }

        foreach ($let in $letters)
        {
            if ($drive_letters -notcontains $let)
            {
                $available_drives += $let
            }
        }               
        [array]::Reverse($available_drives)
        $chosen_letter = $available_drives[0]

        write-host "talen drives: $taken_drives"

        write-host "attempting to create $chosen_letter on $sharepath"


        New-PSDrive -Name $chosen_letter -Persist -PSProvider "FileSystem" -Root $SharePath -Credential $cred

        $testpath = $chosen_letter + ":\"
        
        if (Test-Path -Path $testpath)
        {
            return $testpath
        }

        else 
        {
            test-path -path $testpath
            throw "Couldn't map a valid network drive on $computername with driveletter $chosen_letter to share $sharepath"
        }

    }   
}